@@ -48,8 +48,8 @@ BehaviorSettingsPage::BehaviorSettingsPage(const QUrl& url, QWidget* parent) :
 
 
     // View properties
-    m_globalViewProps = new QRadioButton(i18nc("@option:radio", "Use common properties for all folders"));
-    m_localViewProps = new QRadioButton(i18nc("@option:radio", "Remember properties for each folder"));
+    m_globalViewProps = new QRadioButton(i18nc("@option:radio", "Use common display style for all folders"));
+    m_localViewProps = new QRadioButton(i18nc("@option:radio", "Remember display style for each folder"));
     m_localViewProps->setToolTip(i18nc("@info", "Dolphin will create a hidden .directory file in each folder you change view properties for."));
 
     QButtonGroup* viewGroup = new QButtonGroup(this);
